
From: Albert Herranz <albert_herranz@yahoo.es>

The following patch prevents the crash dump helper code found within kexec
from breaking ppc which still lacks crash dump functionality.

ksysfs crash_notes attribute handling was left under CONFIG_KEXEC for
simplicity although it is not strictly kexec related.

We provide here a dummy definition for crash_notes on ppc.

Signed-off-by: Albert Herranz <albert_herranz@yahoo.es>
Cc: Eric Biederman <ebiederm@xmission.com>
Cc: Vivek Goyal <vgoyal@in.ibm.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ppc/kernel/machine_kexec.c |    6 ++++++
 include/asm-ppc/kexec.h         |    2 ++
 2 files changed, 8 insertions(+)

diff -puN arch/ppc/kernel/machine_kexec.c~kexec-ppc-fix-for-ksysfs-crash_notes arch/ppc/kernel/machine_kexec.c
--- 25/arch/ppc/kernel/machine_kexec.c~kexec-ppc-fix-for-ksysfs-crash_notes	Mon Jul 11 15:13:03 2005
+++ 25-akpm/arch/ppc/kernel/machine_kexec.c	Mon Jul 11 15:13:03 2005
@@ -28,6 +28,12 @@ typedef NORET_TYPE void (*relocate_new_k
 const extern unsigned char relocate_new_kernel[];
 const extern unsigned int relocate_new_kernel_size;
 
+/*
+ * Provide a dummy crash_notes definition while crash dump arrives to ppc.
+ * This prevents breakage of crash_notes attribute in kernel/ksysfs.c.
+ */
+void *crash_notes = NULL;
+
 void machine_shutdown(void)
 {
 	if (ppc_md.machine_shutdown)
diff -puN include/asm-ppc/kexec.h~kexec-ppc-fix-for-ksysfs-crash_notes include/asm-ppc/kexec.h
--- 25/include/asm-ppc/kexec.h~kexec-ppc-fix-for-ksysfs-crash_notes	Mon Jul 11 15:13:03 2005
+++ 25-akpm/include/asm-ppc/kexec.h	Mon Jul 11 15:13:03 2005
@@ -27,6 +27,8 @@
 
 #ifndef __ASSEMBLY__
 
+extern void *crash_notes;
+
 struct kimage;
 
 extern void machine_kexec_simple(struct kimage *image);
_
